nwb2bids Documentation
======================

Summary
-------

nwb2bids reorganizes NWB files into a BIDS directory layout.

Contents
--------

.. toctree::
   :maxdepth: 2

   api/index


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
